package main

import (
	"flag"
	"fmt"
	"log"
	"net"
	"os"
	"time"
)

var port = flag.Int("port", 9100, "The port number to listen on")

func main() {
	flag.Parse()

	listener, err := net.Listen("tcp", fmt.Sprintf(":%d", *port))
	if err != nil {
		fmt.Println("Error listening:", err.Error())
		os.Exit(1)
	}
	defer listener.Close()

	fmt.Printf("Server listening on :%d\n", *port)

	for {
		conn, err := listener.Accept()
		if err != nil {
			fmt.Println("Error accepting: ", err.Error())
			os.Exit(1)
		}
		go handleRequest(conn)
	}
}

func handleRequest(conn net.Conn) {
	log.Println("Incoming connection")
	defer conn.Close()

	buf := make([]byte, 1024)

	total := 0
	for {
		n, err := conn.Read(buf)
		total += n
		if err != nil {
			if err.Error() != "EOF" {
				fmt.Println("Read error:", err)
			}
			break
		}
	}
	log.Printf("Finished Receiving %d bytes, waiting before sending something", total)

	// Send back the string before closing
	for i := 1; i < 21; i++ {
		toSend := fmt.Sprintf("%06d\n", i)
		log.Println("Sending data")
		n, err := conn.Write([]byte(toSend))
		if err != nil {
			log.Printf("Error sending data - %d bytes sent - %v", n, err)
		}
		if n != len(toSend) {
			log.Printf("Warning - sent %d/%d bytes", n, len(toSend))
		}
		time.Sleep(100 * time.Millisecond)
	}
	fmt.Println("Connection closed with ", conn.RemoteAddr())
}
